#
# spec file for package pyradio
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019-2023 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pyradio
Version:        0.9.3.9
Release:        bp160.1.6
Summary:        Curses based internet radio player
License:        MIT
URL:            https://www.coderholic.com/pyradio
Source0:        https://github.com/coderholic/pyradio/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       pyradio-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base >= 3.9
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       python3-rich
Recommends:     vlc-noX
BuildArch:      noarch

%description
A command line Internet radio player based on curses, that uses external media
players to perform the actual playback. It currently supports the following
players: MPV, MPlayer and VLC.

%prep
%autosetup
chmod -x pyradio/notification

%build
export LC_ALL=en_US.utf8
%python3_pyproject_wheel

%install
%python3_pyproject_install
install -Dm0644 -t %{buildroot}%{_mandir}/man1/ docs/pyradio*.1
install -Dm0644 -t %{buildroot}%{_docdir}/%{name}/ docs/*.md
%fdupes %{buildroot}%{python3_sitelib}

#%%check
# no tests upstream

%files
%doc Changelog README.md
%license LICENSE
%{_bindir}/pyradio
%{_bindir}/pyradio-client
%{_docdir}/%{name}
%{_mandir}/man1/pyradio*.1%{?ext_man}
%{python3_sitelib}/pyradio
%{python3_sitelib}/pyradio-%{version}.dist-info

%changelog
* Wed Aug 21 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- Update to version 0.9.3.9
  * fixing a crash when adding a station to favorites
- Changes from version 0.9.3.8
  * pressing "*" will add the selected station to favorites
  * adding the possibility to declare a "Referer URL" for a station
  * pyradio-client: /title will actually report the song title
  * pyradio-client: beautifying output
  * removing more python 2 code
  * updating docs
- Changes from version 0.9.3.7
  * introducing the pyradio-client program
  * adding three more System Themes
  * do not allow to change the Recording Directory while recording
    is on either in this instance or a headless instance
  * fix PyRadioOpenDir: always open dir
  * PyRadioRecordingDir: adding key 'd' to revert to deault
  * fixing default opener detection
  * if a linux opener is enetered but config not saved, and opener
    window is opened again, display the one entered instead of the
    saved opener
  * fix stop mkvmerge recursive execution
  * Remote Control Server: adding a warning to the info response,
    if PyRadio is not in Main Mode
  * Remote Control Server: introducing the /reconfig command
  * Desktop Notifications: stations icons are now being cached
  * config: adding parameter remove_station_icons, to remove
    downloaded files on program exit
- Changes from version 0.9.3.6
  * fixing #241 - pyradio-recordings folder keeps showing in home directory
  * When XDG compliance is forced due to both XDG_DATA_HOME and XDG_STATE_HOME
    directories already exist, update the local Desktop file, so that the
    Icon point to its new location
  * fixing typos
- Changes from version 0.9.3.5
  * Config Window changes:
  * when r / d (revert to saved / default params) is typed,
    correctly load the corresponding theme
  * do not use hardcoded values when loading default params
  * do not toggle transparency when repeatedly pressing r / d
  * do not change transparency settings when themes are not being used
  * fixing cursor positioning for PgDn
  * XDD compliant operation changes:
  * if both XDG_DATA_HOME and XDG_STATE_HOME directories already exist,
    xdg_compliant will be set to True, even if not set in the
    configuration file (it means an XDG migration has been performed
    in the past; using the non-XDG dirs will lead to data loss)
  * suppress list of files moved when migrating to XDG dirs
  * Theming changes:
  * preserve theming config options when a terminal that does not
    support color change is used and config is saved
  * adding "Color Factor" parameter to themes
  * Linux Vistual Console
  * adding config option console_theme; this way either the dark
    or the light theme can be used when on the console
  * detect execution on the Virtual Console
  * do not open HTML help
  * display list of directories when \o is pressed
  * do not issue desktop notifications
  * clear console at exit
  * fixing #240 - AttributeError: NoneType object has no attribute page
  * actually open playlists list ('o') or RabioBrowser ('O'), after a
    dirty palylist save query has been performed
  * updating Windows Media Players links
  * updating docs
- Changes from version 0.9.3.4 (BUG FIX)
  * adding --no-video command line parameter for vlc
  * removing more python 2 code
  * updating macOS installation instructions (based on Ventura)
  * fixing #239 - Pyradio doesn't remember warning message was already shown
  * fixing loading saved and default config options in Config Window,
    Recording Dir is excluded from change
  * updating docs
- Changes from version 0.9.3.3 (BUG FIX)
  * adding a resource opener parameter for linux installations
  * fixing issues #236 and #237
  * fixing several minor bugs
- Changes from version 0.9.3.2 (BUG FIX)
  * fixing #233 (move .registers to state dir)
  * fixing stations.csv (from erroneous PR #227)
  * updating headless.md
- Changes from version 0.9.3.1 (BUG FIX)
  * fixing #231 - [BUG] pyradio-0.9.3 cannot be executed
  * closing #232 - [BUG] self.xdg.xdg_compliant = False
- Changes from version 0.9.3
  * user config file will not be automatically created; it will be
    created only when some parameter value is different to the one
    set in the package config file
  * adding -pc (--print-config) command line option
  * adding the xdg_compliant config option (packagers option)
    if set to True, config dir contents will be moved to XDG Base
    dir (https://wiki.archlinux.org/title/XDG_Base_Directory)
  * RadioBrowser: present next previous result pages
  * RadioBrowser: adding Icon to station DB info
  * Remote Control Server: adding commands relevant to RadioBrowser results
    page navigation (text interface) and relevant web interface buttons
  * Remote Control Server: adding REC button to web interface
  * Remote Control Server: the output of the /info command will report
    headless operation and if RadioBrowser is active, search term used and
    page number
  * introducing the Messaging System; most messages displayed to the user
    have been transfered to messages_system.py
  * moving Pyradio cache contents to ~/.cache (not on Windows)
  * moving the recordings directory to home folder and renaming it to
    "pyradio-recordings".
  * adding recording_dir config parameter and window to customize it
  * titles log files will be saved in the recordings directory
  * if netifaces module is not installed, headless operation will be aborted
  * fixing #229: Crash when $HOME/.mplayer directory does not exist
  * fixing escaped chars in window title and litles log file
  * adding a Windows python 3.12 workaround to the "curses silently exits" bug
  * adding two Serbian stations in station.csv - PR #227
  * updating documentation
* Fri Mar  1 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.2.25
  * droping python 2 - PyRadio will only run on python 3
  * fixing #228
- version 0.9.2.24 (BUG FIX)
  * fixing mpv title parsing (once again)
  * fixing "Genre" field wrapping on Starion Info window
- version 0.9.2.23 (BUG FIX)
  * fixing issue #224 - crash when "artist", "album", "year"
    string in received data
- version 0.9.2.22 (BUG FIX)
  * fixing bug #222 - Appending a radio station with A in a playlist
    leads to a crash (when number stations is less than window height)
  * fixing a crash that would occur when pressing ENTER on the Cancel
    button of the "rename playlist" and "new playlist" window
- version 0.9.2.21
  * adding --headless command line parameter and functionality
  * adding the --address command line parameter
  * recorded files will always be saved in the recordings folder
    If mkvtoolnix is present, a tmp_ prefix will be used to record
    the raw file, which will be removed after chapters integration
  * the message to indicate failure to connect to RadioBrowser will
    be displayed for 2 seconds (instead of requiring a key press)
  * mpv will read the "artist" and "title" fields from station response (#217)
  * remote control server: adding functionality for RadioBrowser
  * remote control server: do not disable individual buttons
  * remote control server: will restart if crashed
  * remote control server: can now accept real IPs (config option)
  * introducing "remote control server lock" files
  * trying to fix "pipx not found" on MacOS again
  * fixing config window rendering bug (#215)
  * fixing cover insertion to mkv files
  * fixing escape character warnings for python 3.12
  * fixing lock refresh issues
  * working on scheculer (not available yet)
  * updating win mplayer link
  * creating issues templates
  * updating documentation
- version 0.9.2.20
  * Creating the docs folder and moving files there
  * Updating pyproject.toml and setup.py for the latest
    Installation method changes
  * Working on scheduler (not applicable yet)
  * Updating docs
- version 0.9.2.19 (BUG FIX release)
  * cover.png updated
  * make sure cover.png is in the data folder
  * fix "No chapters found" message when recorded file has
    less than 3 chapter markers
- version 0.9.2.18
  * fixing a crash on mkvtoolnix.py
- version 0.9.2.17
  * Recorded MKV files will have a cover image by default
    (when MKVToolNix is installed)
  * Adding -mkv, -scv, -srt, -ach and -lr command line parameters
    (applicable when MKVToolNix is installed)
  * Rearranging and grouping options in the program's help screen
  * Working on scheduler (not applicable yet)
  * Updating docs
- version 0.9.2.16
  * install.py: will terminate if python not in PATH
  * recorded files will have tags inserted in them if mkvmerge
    is detected. Chapters will also be added if the station
    provides ICY Titles
  * opening the config folder while recording will actually open the
    recording folder
  * buffering can now be disabled (in 0.9.2.15, once buffering was
    enabled, it could not be disabled until program termination)
  * fixing a couple of race conditions (threading lock files not being
    released) that would lead to a freeze
  * fixing players crash detection routines
  * fixing config players parsing
  * on Windows, downloaded recording files in the data directory
    will be deleted at startup, when recording is not active
  * adding recording man page
  * Updating docs
- version 0.9.2.15 (BUG FIX)
  * fixing mplayer and vlc recording
  * mplayer buffering min changed to 250KB
  * fixing updateRecordingStatus not exiting when asked
  * buffer size cannot be 0
- version 0.9.2.14
  * adding players buffering
  * [B] will be displayed at top left corner of the window
    when player is buffering
  * adding "Force transparency" config option (as per #201)
  * redisigning players' extra parameters window
  * removing command line parameters -ep, -ap, lp
    and changing -ocd etc.
  * Windows: MPV installation will check CPU flags to
    download V3 or normal mpv release
  * fix_pyradio_desktop_file: parameters will be placed
    after terminal name (before -e)
  * fixing mpv parameter which might throw a warning
    which would break the TUI
  * fixing mplayer volume parsing error
  * fixing a couple of python2 crashes
  * updating build_install_pyradio (as per #203)
  * updating docs
- Update pyradio-rpmlintrc
- Install markdown docs and more manpages
- Build PEP517 wheel
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.2.13:
  * all search widgets will save up to 20 of their last search
    terms
  * VLC will now save its default volume
  * adding --record command line parameter
  * \l will toggle the "Open last playlist" config setting
  * updating docs
  * Implementing VLC recorder (not for Windows)
  * MPlayer recorder will display volume level
  * MPlayer on Windows 7 will not use profiles
  * Trying different recorded file limit to start monitor
  * updating docs
* Fri Jul  7 2023 malcolmlewis@opensuse.org
- Add requires on python3-rich, (boo#1213136).
* Mon Jun 26 2023 malcolmlewis@opensuse.org
- Updated to version 0.9.2.11:
  + Not updated in some time!. Many small releases, please see
    /usr/share/doc/packages/pyradio/Changelog.
- Add pyradio-rpmlintrc to ignore zero length notification file.
* Mon Sep  6 2021 malcolmlewis@opensuse.org
- Updated to version 0.8.9.9:
  * Search history navigation will work with normal keys in
    addition to Control-key combinations (when a line editor does
    not have the focus).
  * When navigating to a new search term, in the RadioBrowser
    Search Window, the two main check boxes will always get the
    focus (makes it easier to navigate using normal keys).
  * Docs Updated
- Changes from version 0.8.9.8:
  * Fixing RadioBrowser history save confirmation window.
  * Interchanging ^T and ^Y in the RadioBrowser Search Window.
  * Addinf FULL_SCREEN_MODES for farter rendering.
- Changes from version -.8.9.7:
  * All Search Window movement keys (^N, ^P, ^Y) ill add a new
    history item (if possible).
  * ^B does not save history to file.
  * Do not close browser if network fails.
- Changes from version 0.8.9.7:
  * RadioBrowser History Management finalized.
  * Fields' placement fixed in RadioBrowser Search Window.
  * RadioBrowser readme page added.
  * Docs updated.
- Changes from 0.8.9.2:
  * Screen flickering when moving within the stations' list
    eliminated.
  * VLC player is available again (disabled by unreported bug).
  * Advancing Radio Browser support.
  * Fixing python 2 return from Radio Browser TUI breakage.
  * Adding dnspython module availability check.
- Changes from version 0.8.9.1:
  * Implemented the so called "Listening" mode, in which PyRadio
    TUI can be reduced down to a single line (the "Status Bar").
    Requested for tilling WM use, (gh#coderholic/pyradio#128).
- Changes from version 0.8.9:
  * Implemented a simplified method to install, update, uninstall.
  * PyRadio will detect its player abnormal termination.
  * Player's connection timeout can now be disabled. Once a player
    is started, it will be considered to be connected immediately.
  * stations.csv changes can now be integrated into user's
    stations.csv.
  * mplayer "pyradio" profile will use the internal mixer to adjust
    volume.
  * BUG FIX: Active players parameter list is always synchronized
    to saved.
  * BUG FIX: Clicking on empty space (past last station) will not
    crash pyradio.
- Changes from version 0.8.8.5:
  * Fixing -ap value not activated by player.
  * Commenting out excessive error log messages.
- Changes from version 0.8.8.4:
  * Fixing double click behavior (while in playback double clicking
    to a different station will start it.
  * vcl will not start muted (volume = 0)
- Changes from version 0.8.8.3:
  * Basic mouse support implemented.
  * Config option to enable mouse support added.
  * Implementing players extra parameters set.
  * Player selection Config window redesigned.
  * Adding -ep. -ap, -lp command line parameters.
  * Fixing a bug which would lead to a crash when "r" would be
    pressed in the config window.
  * Playback will be restarted when vital parameters are changes
    (encoding, connection type, player parameters).
  * When restarting playback, play the correct station not the
    selected one.
  * Adding autostart BAT file on Windows to prevent session locking
    when Windows terminate while PyRadio is still running.
  * pyradio will always use a profile
  * Fixing several minor bugs.
- Changes from version 0.8.8.2:
  * Gracefully exit when the terminal is closed.
- Changes from version 0.8.8.1:
  * Restarting radio-browser.info implementation.
- Changes from version 0.8.8:
  * Implementing "Paste to playlist" (\p) command.
  * Implementing "Create Playlist" (\n).
  * Addind \u (show Unnamed Register) command.
  * Fixing volume display for MPV on python3 before a valid Title
    has been received.
  * Revert to stations playlist if default one (set by config) does
    not exist.
  * Second level config windows will not be displayed when main
    window shows "Window too small" message.
  * When opening a playlist/register from register mode, continue
    playing active station (if found in opened playlist/register).
  * Do not show "'" when opening a playlist/register from register
    mode.
  * "Title: (null)" will not appear any more (vlc).
* Sun Mar  1 2020 malcolmlewis@opensuse.org
- Update to version 0.8.7.1:
  * Fixing mpv playlist option (for mpv 0.32.0).
* Wed Jan  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the download url.
* Thu Jan  2 2020 malcolmlewis@opensuse.org
- Updated to version 0.8.7:
  * Fixing volume issue with mpv 0.30.0.
  * mpv on python3 uses socket only (no stdout parsing).
  * socat is no longer needed to use mpv.
  * Player's config file will be saved even if it does not already
    exist.
- Changes from version 0.8.6:
  * Adding playlist history (for local playlists).
  * https URLs will be converted to http before connecting.
  * Fixing station moving when appending station.
  * Config / Default station: pading fixed.
- Changes from version 0.8.5:
  * PyRadio will not crush with mpv 0.30.0, changing mpv's volume
    is still possible, but no info will be presented on the Status
    Bar. Furthermore, saving mpv's volume will not be possible,
    (gh#mpv-player/mpv#7153).
  * When the default played is changed in the config, a message
    to restart the application is presented to the user.
  * Config / Default station: pading fixed.
* Fri Nov 15 2019 malcolmlewis@opensuse.org
- Initial build at version 0.8.4.
